import { Utilities } from '@/util/Utilities';
import { DialogService, LoadingService } from '@zeedhi/common';
import { Http, Loader, Metadata } from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class Sm00011000TabItensApuracaoFaturamentoController {
    public tabApuracaoFaturamento = Loader.getInstance('Sm00011000TabApuracaoFaturamentoController');

    public prepararApurarItens() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-tab-itens');
        const selectedrows = grid.selectedRows;
        if (grid.selectedRows.length > 0) {
            const linhasPendentes = selectedrows.filter((row) => row.IDSITUACAO === '1');
            if (linhasPendentes.length === selectedrows.length) {
                this.showConfirmDialogMessage('Deseja realmente apurar os itens selecionados?', linhasPendentes);
            } else if (linhasPendentes.length < selectedrows.length && linhasPendentes.length > 0) {
                this.showConfirmDialogMessage('Deseja realmente apurar os itens selecionadas?<br><br>Obs: Alguns dos itens selecionados não estão com a situação Pendente. Estes itens serão desconsideradas.', linhasPendentes);
            } else {
                Utilities.showDialogMessage('warning', 'Operação bloqueada!', 'Os itens selecionados não estão pendentes.');
            }
        } else {
            Utilities.showDialogMessage('error', 'Operação bloqueada!', 'É necessário selecionar um registro');
        }
    }

    public showConfirmDialogMessage(text: string, linhasPendentes: any) {
        DialogService.show({
            name: 'warning_dialog',
            type: 'warning',
            title: 'Confirmação',
            text,
            buttons: [
                {
                    name: 'button-no',
                    component: 'ZdButton',
                    label: 'Não',
                    events: {
                        click: () => DialogService.hide(),
                    },
                    outline: true,
                },
                {
                    name: 'button-yes',
                    component: 'ZdButton',
                    label: 'Sim',
                    events: {
                        click: () => {
                            LoadingService.show();
                            this.gerarFaturamentoApuracao(linhasPendentes);
                            DialogService.hide();
                        },
                    },
                },
            ],
        });
    }

    public gerarFaturamentoApuracao(linhasPendentes: any) {
        let itens = '_';
        linhasPendentes.forEach((contItens: any) => {
            if (contItens.NRITFATURACONT != null) {
                itens = `${itens}${contItens.NRITFATURACONT}_`;
            }
        });
        const nritfaturacont = itens;
        const rateios = null;
        const vencimentos = `_${this.tabApuracaoFaturamento.currentRow.NRFATURACONT}_`;
        const params = {
            P_NRFATURACONT: vencimentos,
            P_NRRATEIOITEMFAT: rateios,
            P_NRITFATURACONT: nritfaturacont,
        };
        const gridItens = Metadata.getInstance<TekGrid>('basic-tek-grid-tab-itens');
        Http.post('/gerarFaturamentoApuracao', params)
            .then(() => {
                gridItens.selectedRows = [];
                gridItens.datasource.get();
                Utilities.showSuccessMessage();
            }).catch(() => {
                gridItens.selectedRows = [];
                Http.get('/getModalErroApuracaoFaturamento')
                    .then((retorno) => {
                        const erro = retorno.data.data[0].DSERRO;
                        DialogService.show({
                            name: 'error-dialog-validacao',
                            type: 'error',
                            title: 'Atenção',
                            text: `Operação bloqueada!<br><br>${erro}`,
                        });
                    });
            }).finally(() => {
                LoadingService.hide();
            });
    }
}
