import {
    Http, Metadata,
} from '@zeedhi/core';
import {
    LoadingService, IGridEvent, DialogService, TextInput,
} from '@zeedhi/common';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import { Utilities } from '@/util/Utilities';

export class Sm00057001ConfiguracaoRegionalIdiomaController {
    public adicionarConfiguracaoRegionalIdioma() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-idioma');
        const newId = 0;
        grid.addNewRow({ CDIDIOM: newId, IDPADRAO: 'N', IDATIVO: 'S' }, 'start');
        setTimeout(() => {
            const nameInput = Metadata.getInstance<TextInput>(`NMIDIOMA_editable_${newId}`);
            nameInput.setFocus();
        }, 100);
    }

    public inserirConfiguracaoRegionalIdioma({ event }: IGridEvent) {
        event!.preventDefault();
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-idioma');
        const idiomas = grid.getEditedRows();

        if (Utilities.validateGrid(grid)) {
            LoadingService.show();
            Http.post('/inserirConfiguracaoRegionalIdioma', idiomas).then(() => {
                grid.cancelEditedRows();
                grid.reload();
                Utilities.showSuccessMessage();
                grid.datasource.get();
            }).catch((error) => {
                if (error.response.data.error === 'IDIOMA JÁ EXISTE') {
                    Utilities.alertMessage('Não é possivel adicionar um idioma existente', 'error');
                } else {
                    Utilities.showErrorMessage(error);
                }
            }).finally(() => {
                LoadingService.hide();
            });
        }
    }

    public dialogDeletarConfiguracaoRegionalIdioma({ event }: any) {
        Utilities.showConfirmDeleteMessage(event, 'Sm00057001ConfiguracaoRegionalIdiomaController.deletarConfiguracaoRegionalIdioma');
    }

    public deletarConfiguracaoRegionalIdioma() {
        DialogService.hide();
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-idioma');
        LoadingService.show();
        Http.post('/deletarConfiguracaoRegionalIdioma', grid.selectedRows).then(() => {
            grid.selectedRows = [];
            grid.cancelEditedRows();
            grid.reload();
            Utilities.showSuccessMessage();
        }).catch((error) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }
}
